@@ -58,14 +58,14 @@ class DBBase:
 
     def __executeParam(self, cursor, sql, Param):
         if not Param:
-            self.__log_cls.debug(sql)
+            self.__log_cls.info(sql)
             return cursor.execute(sql)
         else:
             if isinstance(Param, dict):
-                self.__log_cls.debug(sql % Param)
+                self.__log_cls.info(sql % Param)
                 return cursor.execute(sql, Param)
             else:
-                self.__log_cls.debug(sql % Param)
+                self.__log_cls.info(sql % Param)
                 return cursor.execute(sql % Param)
 
     def handleMany(self, result):
